import processing.video.*;                         //video library muss installiert sein

Capture cam;                                       //Kamera object 
String[] cameras;                                  //Liste der verfügbaren Kameras
int [] intervals = {1,2,3,5,10,20,30,60};          //Liste der auswählbaren Intervalle
int interval = 0;                                  //Index des ausgewählten Intervalls (Standart 0)
boolean record = false;                            //läuft die Aufnahme oder nicht
boolean camselected = false;                       //ist eine Kamera ausgewählt oder nicht
int framerate = 30;                                //Framerate mit der der Sketch läuft
   

void setup() {
  size(1400, 720);                                 //Fenstergröße(passt für 720p video) 
  surface.setResizable(true);                      //Fenstergröße kann angepasst werden
  frameRate(framerate);                            //Framerate setzen
  textSize(15);                                    //Textgröße setzen 
  cameras = Capture.list();                        //Liste der verfügbaren Kameras speichern
 }

void draw() {
  background(255);                                 //Weißer Hintergrund
  if(!camselected){                                //wenn keine Kamera ausgewählt ist: Auswahlansicht
    if (cameras.length == 0) {                        //wenn keine Kamera verfügbar is
      fill(0);                                            //schwarzer
      text("No cameras available!",10,10);                //Text
                
    }
    else {                                            //wenn Kameras verfügbar
      text("Available cameras:",10,10);                
      for (int i = 0; i < cameras.length; i++) {      //für jede Kamera eine Zeile mit einer Auswahlbox
        noFill();                                    
        rect(20,20+20*i,20,20);
        fill(0);
       text(cameras[i],45,35+20*i);
      }
    }
  }
  else{                                                //wenn eine Kamera ausgesucht ist: Anzeigeansicht
  
  if (cam != null && cam.available() == true) {        //Bild von der Kamera einlesen, wenn eines bereit steht
    cam.read();
    
  }
    fill(0);                                            //Schaltfläche zum Ändern der Kamera
    text("Change cam",25,35);
    noFill();                                         
    rect(0,20,20,20);
    
    fill(0);
    text("Record",25,55);                              //Aufnahme - Schaltfäche 
    if(record){                                        // rot füllen bei laufender Aufnahme
      fill(255,0,0); 
     }
     else{                                             //nicht füllen, wenn keine Aufnahme läuft
      noFill(); 
     }
     rect(0,40,20,20);
    
     fill(0); 
     text("every ",25,85);
     
     for(int i=0; i<intervals.length; i++){            //für jedes Intervall in der Liste
       fill(0);
       text(str(intervals[i])+" sec",25,105+20*i);       //den Wert anzeigtn
       if(i == interval){                                //die ausgewählte Schaltfläche schwarz füllen  
        fill(0); 
       }
       else{                                             //die anderen nicht füllen
        noFill(); 
       }
       rect(0,90+20*i,20,20);                            //die Schaltfächen anzeigen
     }
         
     //frameCount zählt die Frames seit der Sketch gestartet wurde
     //framerate * das ausgesuchte Intervall = Anzahl der Frames in einem Intervall
     //Der % (Modulo-Operator) gibt den Rest einer Division aus. Wenn das Ergebnis 0 ist, ist frameCount ein Vielfaches
     //der Anzahl der Frames in einem Intervall also ist ein Intervall vergangen.
     
     if (frameCount%(framerate*intervals[interval])==0 && record) {
     //Das Bild im frames-Ordner abspeichern mit seinem frameCount als Name
     //WICHTIG: den Ordner vor einer neuen Aufnahme leeren!
       cam.save("frames/"+str(frameCount)+".jpg");        
      }
      
     if(cam!=null){
      image(cam, 120, 0);                                 //Bild anzeigen
      }
  }
 
}

//Benutzereingabe
void mouseClicked(){
  if(!camselected){                                       //wenn keine Kamera ausgewählt ist
                                                         
         //wenn der Click in einer der Auswahlboxen war
    if(mouseX>19&&mouseX<41&&mouseY>19&&mouseY<21+cameras.length*20){
         
         //Konstruktor für das Kamera-Objekt
         //Um den Index der ausgesuchten Kamera zu bekommen, wird vom mouseY-Wert der Y Wert der obersten Box abgezogen,
         //und das Ergebnis durch die Boxhöhe dividiert.
           
      cam = new Capture(this, cameras[(mouseY-20)/20]);
      cam.start();                                          //die Kamera starten 
      camselected = true;                                   //auf die Anzeige-Ansicht wechseln
      
     }
  }
  else{                                                     //wenn eine Kamera ausgewählt ist
    if(mouseX<21&&mouseY>19&&mouseY<41){                    //wenn click in der "change cam" - Box
      record = false;                                       //Aufnahme stoppen
      cam.stop();                                           //Kamera stoppen
      camselected = false;                                  //in die Auswahlansicht wechseln
    }
    if(mouseX<21&&mouseY>40&&mouseY<61){                    //wenn click in der "record" - Box
       record = !record;                                    //zwischen Aufnahme - keine Aufnahme wechseln
    }
    
    //den Index des ausgewählten Intervalls mit der gleichen Methode wie für Kameraauswahl ermitteln
    
    if(mouseX<21&&mouseY>90&&mouseY<intervals.length*20+90){
       interval = (mouseY-90)/20;
       
    }
  }
}


void keyPressed() {            //zwischen Aufnahme - keine Aufnahme wechseln mit der 'r' Taste
  if (key=='r') {
    record=!record;
  }
 }